from PIL import Image, ImageDraw, ImageFilter


class PicStyleClass:
    def __init__(self) -> None:
        pass

    def border_radius(self, img: Image.Image, radius: int):
        '''
        为图像生成圆角
        :param img 需要处理的图像
        :param radius 圆角半径
        return {Image.Image} 处理后的图像
        '''
        # 处理原图并获取基本信息
        img = img.convert('RGBA')
        w, h = img.size

        # 生成一个宽为圆角直径的黑色方块
        img_rec = Image.new('L', (radius * 2, radius * 2), 0)
        # 创建绘制对象
        draw = ImageDraw.Draw(img_rec)
        # 方块内绘制一个内切白色圆形
        draw.ellipse((0, 0, radius * 2, radius * 2), fill=255)

        # 创建一个alpha层，存放四个圆角，使用透明度切除圆角外的图片
        alpha = Image.new('L', img.size, 255)

        # 粘贴左上角
        alpha.paste(img_rec.crop((0, 0, radius, radius)), (0, 0))
        # 粘贴右上角
        alpha.paste(img_rec.crop(
            (radius, 0, radius * 2, radius)), (w - radius, 0))
        # 粘贴左下角
        alpha.paste(img_rec.crop(
            (0, radius, radius, radius * 2)), (0, h - radius))
        # 粘贴右下角
        alpha.paste(img_rec.crop((radius, radius, radius * 2, radius * 2)),
                    (w - radius, h - radius))
        # alpha替换，白色透明，黑色隐藏
        img.putalpha(alpha)

        # 绘制圆角边框
        # draw = ImageDraw.Draw(img)
        # print(img.getbbox())
        # draw.rounded_rectangle(img.getbbox(),
        #                        outline="black",
        #                        width=3,
        #                        radius=radius)
        return img

    def box_shadow(self, img: Image.Image,
                   bgcolor: str = 'white',
                   shadowcolor: str = '#666666',
                   offset: tuple = (0, 0),
                   border: int = 10,
                   radius: int = 5):
        '''
        为图像增加阴影
        :param img 需要处理的图像
        :param bgcolor 阴影图层背景色，默认white
        :param shadowcolor 阴影颜色，默认#666666
        :param offset 阴影偏移量，默认(0,0)不做任何偏移，建议为偶数，遵循左、上原则
        :param border 边框宽度，默认你10，容纳阴影的范围
        :param radius 模糊半径，默认50，值越大模糊越多
        return {Image.Image} 处理后的图像
        '''
        # 处理原图并获取基本信息
        img = img.convert('RGBA')
        w, h = img.size

        # 创建阴影图层
        SHADOW_W = w + abs(offset[0]) + border * 2
        SHADOW_H = h + abs(offset[1]) + border * 2
        img_shadow = Image.new(img.mode, (SHADOW_W, SHADOW_H))

        # 绘制阴影
        SHADOW_LEFT = border + max(offset[0], 0)
        SHADOW_TOP = border + max(offset[1], 0)
        img_shadow.paste(
            shadowcolor,
            [SHADOW_LEFT, SHADOW_TOP, w + SHADOW_LEFT, h + SHADOW_TOP])
        for i in range(radius):
            img_shadow = img_shadow.filter(ImageFilter.BLUR)
        img_shadow.show()

        # # 为阴影添加圆角
        # img_shadow=border_radius(img_shadow,120)

        # 组合图像
        IMG_LEFT = border - min(offset[0], 0)
        IMG_TOP = border - min(offset[1], 0)
        img_shadow.paste(img, (IMG_LEFT, IMG_TOP), img)

        return img_shadow



from genericpath import isdir, isfile
from importlib.resources import path
from operator import truediv
import os


class FileClass:
    def __init__(self):
        pass

    def exists(self, path: str, type: str = 'dir'):
        '''
        判断文件或目录是否存在
        :param path 完整的文件/目录地址，如：/User/File或/User/File/hello.py
        :param type dir/file，默认dir
        return {bool} True存在，False不存在
        '''
        if (os.path.isdir(path) and type == 'dir') or (os.path.isfile(path) and type == 'file'):
            return os.path.exists(path)
        return False

    def mkdir(self, path: str, name: str):
        '''
        在指定目录创建目录
        :param path 需要创建目录的路径，如：/User/File
        :param name 目录名称
        return {bool} True创建成功，False创建失败，目录已存在
        '''
        path = path+'/'+name
        if self.exists(path) == True:
            return False
        os.mkdir(path+'/'+name)
        return True


    def rmfile(self,path:str):
        '''
        递归删除目录下所有文件及子目录
        :param path 需要删除的目录，如/User/File
        return {bool} True删除成功
        '''
        cfilepath=self.get_dir_filepath(path)
        dirpath=[]
        for cpath in cfilepath:
            if os.path.isdir(cpath):
                # 如果路径为目录，则保存到目录列表
                dirpath.append(cpath)
            if os.path.isfile(cpath):
                # 如果路径为文件，则删除文件
                os.remove(cpath)
        # 循环删除剩下的空目录
        for dpath in dirpath:
            os.rmdir(dpath)
        return True
        



    def get_dir_filename(self, path: str):
        '''
        获取指定目录下所有子文件名称
        :param path 目录路径
        return {list} 所有子文件名称
        '''
        file_list = []
        for root, dirs, files in os.walk(path):
            for name in files:
                if name == '.DS_Store':
                    continue
                file_list.append(name)
        return file_list

    def get_dir_filepath(self, path:str):
        '''
        获取指定目录下所有子文件绝对路径
        :param path 目录路径
        return {list} 所有子文件路径
        '''
        file_list = []
        for root, dirs, files in os.walk(path):
            for name in files:
                if name == '.DS_Store':
                    continue
                file_path = os.path.join(root, name).replace('\\', '/')
                file_list.append(file_path)
        return file_list

    def get_abspath(self):
        path = os.path.abspath('.')
        return path


if __name__ == '__main__':
    fileclass = FileClass()
    res=fileclass.get_dir_filepath('/Volumes/Files/待处理图片')
    print(res)



import pymysql
import pymssql
import pymongo
from pymoran.strtool import StrClass


class MySQLClient:
    def __init__(self, dbdata: dict) -> None:
        '''
        初始化数据库连接
        :param dbdata(host 主机地址,user 用户名,password 密码,database 数据库,port 端口，默认3306)
        :return {bool} True/False
        '''
        # 打开数据库连接
        self.conn = pymysql.connect(
            host=dbdata['host'],
            user=dbdata['user'],
            password=dbdata['password'],
            database=dbdata['database'],
            port=dbdata['port']
        )
        # 使用cursor()方法获取操作游标
        self.cursor = self.conn.cursor()
        self.strclass = StrClass()

    def close(self):
        self.conn.close()

    def creat_table(self, name: str, field: list, close: bool = True):
        '''
        创建表
        :param name 表名
        :param field 字段列表，例：['id INT AUTO_INCREMENT PRIMARY KEY','name varchar(255)']
        :return {bool} True/False
        '''
        result = False
        sql = 'create table %s (%s)' % (name, (',').join(field))
        try:
            # 执行sql语句
            self.cursor.execute(sql)
            result = True
        except:
            # 如果发生错误则回滚
            self.conn.rollback()
            result = False
        if close:
            self.close()
        return result

    def custom_query(self, query: str, args: tuple=(), close: bool = True):
        '''
        自定义查询语句
        :param table 表名
        :param data 需要插入的数据
        :param close 是否自动关闭数据库连接，默认True
        :return {bool} True/False
        '''
        result = False

        try:
            # 执行sql语句
            self.cursor.execute(query, args)
            # 提交到数据库执行
            self.conn.commit()
            result = True
        except:
            # 如果发生错误则回滚
            self.conn.rollback()
            result = False
        if close:
            self.close()
        return result
        
    def custom_fetch(self, query: str, args: tuple = (), close: bool = True):
        '''
        查询数据，查询条件数据建议使用html_escape转码保证数据查询安全
        :param query 自定义查询语句
        :param args 查询参数元组
        :param close 是否自动关闭数据库连接，默认True
        :return {list} 如没有查询结果则返回None
        '''
        try:
            # 执行SQL语句
            self.cursor.execute(query,args)
            # 获取所有记录列表
            results = self.cursor.fetchall()
        except:
            print("Error: unable to fetch data")
        # 关闭数据库连接
        if close:
            self.close()
        # 没有查询结果则返回None
        if len(results) == 0:
            return None
        return results

    def insert(self, table: str, data: dict, close: bool = True):
        '''
        插入数据，插入的数据内容无需做特殊安全处理，方法内均进行了html转码保存数据
        :param table 表名
        :param data 需要插入的数据
        :param close 是否自动关闭数据库连接，默认True
        :return {bool} True/False
        '''
        result = False
        # 列
        col = []
        # 行
        row = []
        for d in data.keys():
            col.append(d)
            value=self.strclass.html_escape(data[d])
            value=value.replace('\\','\\\\')
            row.append('"'+value+'"')
        sql = 'INSERT INTO %s (%s) VALUES (%s)' % (
            table,
            ','.join(col),
            ','.join(row)
        )
        try:
            # 执行sql语句
            self.cursor.execute(sql)
            # 提交到数据库执行
            self.conn.commit()
            result = True
        except:
            # 如果发生错误则回滚
            self.conn.rollback()
            result = False
        if close:
            self.close()
        return result

    def insert_many(self,
                    table: str,
                    field: list,
                    data: list,
                    close: bool = True):
        '''
        插入数据，插入的数据内容无需做特殊安全处理，方法内均进行了html转码保存数据
        :param table 表名
        :param field 需要插入数据的字段列表
        :param data 需要插入的多条数据[[],[],[]]
        :param close 是否自动关闭数据库连接，默认True
        :return {bool} True/False
        '''
        result = False
        values = []
        for d in data:
            val = '(%s)' % (','.join(str(v) if type(v)!= str else "'"+self.strclass.html_escape(v).replace('\\','\\\\')+"'" for v in d))
            values.append(val)
        sql = 'INSERT INTO %s (%s) VALUES %s' % (table, ','.join(field),
                                                 ','.join(values))
        try:
            # 如果连接断开则重连
            self.conn.ping(reconnect=True)
            # 执行sql语句
            self.cursor.execute(sql)
            # 提交到数据库执行
            self.conn.commit()
            result = True
        except:
            # 如果发生错误则回滚
            self.conn.rollback()
            result = False
        if close:
            self.close()
        return result

    def fetch(self, fields: list, table: str, query: str = '', orderby: dict = None, limit: int = 0, close: bool = True):
        '''
        查询数据，查询条件数据建议使用html_escape转码保证数据查询安全
        :param fields 要查询的字段名
        :param table 表名
        :param query 查询条件，默认为空
        :param orderby 排序，默认为空，例：{'sort':'desc'}
        :param limit 查询条数，默认0则不限制条数
        :param close 是否自动关闭数据库连接，默认True
        :return {list} 如没有查询结果则返回None
        '''
        where_str = ''
        if query != '':
            where_str = 'WHERE %s' % query
        orderby_str = ''
        if orderby != None:
            orderby_arr = []
            for key in orderby.keys():
                orderby_arr.append('%s %s' % (key, orderby[key]))
            orderby_str = 'ORDER BY ' + ','.join(orderby_arr)
        limit_str=''
        if limit!=0:
            limit_str='limit %s' % limit
        sql = 'SELECT %s FROM %s %s %s %s' % (
            ','.join(fields),
            table,
            where_str,
            orderby_str,
            limit_str
        )
        try:
            # 执行SQL语句
            self.cursor.execute(sql)
            # 获取所有记录列表
            results = self.cursor.fetchall()
        except:
            print("Error: unable to fetch data")
        # 关闭数据库连接
        if close:
            self.close()
        # 没有查询结果则返回None
        if len(results) == 0:
            return None
        # 转化查询结果为list
        res_data = []
        col_count = len(fields)
        for result in results:
            col_data = {}
            for col in range(col_count):
                # 处理查询条件中特殊字符``
                field = fields[col].replace('`', '')
                col_data[field] = result[col]
            res_data.append(col_data)
        return res_data

    def fetch_count(self, table: str, query: str = '', close: bool = True):
        '''
        查询数据结果条数，查询条件数据建议使用html_escape转码保证数据查询安全
        :param table 表名
        :param query where后的查询条件，例：id=1 and name='张三'
        :param close 是否自动关闭数据库连接，默认True
        return:int 结果条数
        '''
        where_str = ''
        if query != '':
            where_str = 'WHERE %s' % query
        sql = 'SELECT count(*) FROM %s %s' % (
            table,
            where_str
        )
        results = (0,)
        try:
            # 执行SQL语句
            self.cursor.execute(sql)
            # 获取所有记录列表
            results = self.cursor.fetchone()
        except:
            print("Error: unable to fetch data")
        # 关闭数据库连接
        if close:
            self.close()
        # 没有查询结果则返回None
        return results[0]

    def update(self, table: str, set: dict, query: str = '', close: bool = True):
        '''
        更新数据，插入内容均自动做html_escape处理
        :param table 表名
        :param set 需要修改的内容
        :param query 查询条件，默认为空
        :param close 是否自动关闭数据库连接，默认True
        :return {bool} True/False
        '''
        result = False
        where_str = ''
        if query != '':
            where_str = 'WHERE %s' % query
        set_list = []
        for key in set.keys():
            value = self.strclass.html_escape(set[key])
            # 将字符串中的\替换为\\，防止插入mysql时\符号消失
            value = value.replace('\\', '\\\\')
            set_list.append(
                '%s="%s"' % (key, value)
            )
        sql = 'UPDATE %s SET %s %s' % (
            table,
            ','.join(set_list),
            where_str
        )
        try:
            # 执行SQL语句
            self.cursor.execute(sql)
            # 提交到数据库执行
            self.conn.commit()
            result = True
        except:
            # 发生错误时回滚
            self.conn.rollback()
            result = False
        # 关闭数据库连接
        if close:
            self.close()
        return result

    def delete(self, table: str, query: str = '', close: bool = True):
        '''
        删除数据，查询条件数据建议使用html_escape转码保证数据查询安全
        :param table 表名
        :param query 查询条件，默认为空
        :param close 是否自动关闭数据库连接，默认True
        :return {bool} True/False
        '''
        result = False
        where_str = ''
        if query != '':
            where_str = 'WHERE %s' % query
        sql = 'DELETE FROM %s %s' % (
            table,
            where_str
        )
        try:
            # 执行SQL语句
            self.cursor.execute(sql)
            # 提交到数据库执行
            self.conn.commit()
            result = True
        except:
            # 发生错误时回滚
            self.conn.rollback()
            result = False
        # 关闭数据库连接
        if close:
            self.close()
        return result

class MSSQLClient:
    def __init__(self,dbdata:dict) -> None:
        '''
        初始化数据库连接
        :param dbdata 连接配置，包含server，database
        '''
        self.conn=pymssql.connect(
            server=dbdata['server'],
            database=dbdata['database']
        )
        self.cursor=self.conn.cursor()

    def close(self):
        self.conn.close()

    def find(self,close: bool = True):
        data=[]
        # 关闭数据库连接
        if close:
            self.close()
        return data

    def delete(self,sql,close:bool=True):
        '''
        删除数据，查询条件数据建议使用html_escape转码保证数据查询安全
        :param table 表名
        :param query 查询条件，默认为空
        :param close 是否自动关闭数据库连接，默认True
        :return {bool} True/False
        '''

    def updata(self,sql,close:bool=True):
        # self.cursor.execute(sql)
        # self.conn.commit()
        # 关闭数据库连接
        if close:
            self.close()
        return True

class MongodbClient:
    def __init__(self, db_name:str, client_url:str):
        '''
        初始化数据库连接
        :param db_name 数据库名称
        :param client_url 数据库地址
        '''
        self.client = pymongo.MongoClient(client_url)
        self.db = self.client[db_name]

    def creatDict(self, colName, dictData):
        col = self.db[colName]
        result = col.insert_one(dictData)
        return result

    def insert_one(self, colName, data):
        col = self.db[colName]
        result = col.insert_one(data)
        if result:
            return True
        return False

    def insert_many(self, colName, data):
        col = self.db[colName]
        result = col.insert_many(data)
        return result.inserted_ids

    def find_count(self, colName: str, query: dict):
        col = self.db[colName]
        result = col.count_documents(query)
        return result

    def find_one(self, colName, query, dataname):
        col = self.db[colName]
        result = col.find_one(query, dataname)
        return result

    def find(self, colName, query, dataname, sort_name='_id', sort=1, skip: int = 0, limit: int = 100):
        col = self.db[colName]
        result = col.find(query, dataname).sort(sort_name, sort).skip(skip).limit(limit)
        return result

    def update_one(self, colName, query, data):
        col = self.db[colName]
        result = col.update_one(query, {"$set": data})
        return result

    def delete_one(self, colName: str, query: dict):
        '''
        删除操作
        :param colName 需要操作的表名称
        :param query 操作条件
        return {bool} True/False
        '''
        col = self.db[colName]
        result = col.delete_one(query)
        if result.deleted_count > 0:
            return True
        return False

    def delete_many(self, colName: str, query: dict):
        '''
        删除操作
        :param colName 需要操作的表名称
        :param query 操作条件
        return {bool} True/False
        '''
        col = self.db[colName]
        result = col.delete_many(query)
        if result.deleted_count > 0:
            return True
        return False


if __name__ == '__main__':
    pass



import oss2


class AliyunClass:
    def __init__(self, ossdata: dict):
        '''
        RAM用户的AccessKey信息
        :param ossdata AccessKeyId,AccessKeySecret,endpoint(Endpoint（地域节点）外网访问地址，带https://),bucket_name(Bucket名称)
        '''
        self.auth = oss2.Auth(
            ossdata['AccessKeyId'],
            ossdata['AccessKeySecret']
        )
        self.bucket = oss2.Bucket(
            self.auth,
            ossdata['endpoint'],
            ossdata['bucket_name'],
            connect_timeout=30
        )

    def put_object(self, name, file):
        '''
        上传文件
        :param name 文件名称
        :param file 文件
        '''
        self.bucket.put_object(name, file)

    def get_object(self, key, file_name, style):
        '''
        下载文件
        '''
        self.bucket.get_object_to_file(key, file_name, process=style)

    def delete_object(self, key):
        self.bucket.delete_object(key)



from pymoran import strtool

class MsgClass:
    def __init__(self):
        self.msgdata = {
            'code': -1,
            'msg': '',
            'data': {},
            'other': {}
        }
        self.jsonclass = strtool.JsonClass()

    # def change_datatype(self, byte):
    #     if isinstance(byte, bytes):
    #         return str(byte, encoding='utf-8')
    #     return json.JSONEncoder.default(byte)

    def successMsg(self, msg: str = '', data: dict or list = {}):
        '''
        成功消息
        :param msg 提示内容，默认空
        :param data 回传的内容，默认空字典
        :return {str} Json字符串
        '''
        self.msgdata['code'] = 0
        self.msgdata['msg'] = msg
        self.msgdata['data'] = data
        return self.jsonclass.jsonToDumps(self.msgdata)

    def errorMsg(self, msg: str = ''):
        '''
        错误消息
        :param msg 提示内容，默认空
        :return {str} Json字符串
        '''
        self.msgdata['code'] = -1
        self.msgdata['msg'] = msg
        return self.jsonclass.jsonToDumps(self.msgdata)

    def abnormalMsg(self, msg: str = ''):
        '''
        异常消息
        :param msg 提示内容，默认空
        :return {str} Json字符串
        '''
        self.msgdata['code'] = -2
        self.msgdata['msg'] = msg
        return self.jsonclass.jsonToDumps(self.msgdata)

    def loginMsg(self, data: dict or list = {}):
        '''
        登录成功消息
        :param msg 提示内容，默认空
        :return {str} Json字符串
        '''
        self.msgdata['code'] = 1000
        self.msgdata['msg'] = 'success'
        self.msgdata['data'] = data
        return self.jsonclass.jsonToDumps(self.msgdata)

    def logoutMsg(self):
        '''
        未登录消息
        :return {str} Json字符串
        '''
        self.msgdata['code'] = 1001
        self.msgdata['msg'] = '登录状态已失效，请重新登录！'
        return self.jsonclass.jsonToDumps(self.msgdata)

    def customMsg(self, code: int = 0, msg: str = '', data: dict or list = {}, other: dict or list = {}):
        '''
        自定义消息
        :param code 消息代码，默认0
        :param msg 提示内容，默认空
        :param data 回传的内容，默认空字典
        :param other 其他内容，默认空字典
        :return {str} Json字符串
        '''
        self.msgdata['code'] = code
        self.msgdata['msg'] = msg
        self.msgdata['data'] = data
        self.msgdata['other'] = other
        # if d:
        #     # d参数为True则不进行json转换
        #     return msgdata
        return self.jsonclass.jsonToDumps(self.msgdata)

# class FormCheckClass:
#     '''
#     表单字段验证类
#     '''
#     def __init__(self):
#         self.msgclass = MsgClass()
#         self.return_msg = self.msgclass.abnormalMsg()
#         self.re = strtool.RegularClass()
#         self.strdeal = StrDeal()

#     def check(self, data, **kw):
#         '''
#         表单验证并清洗数据

#         @param data {dict} 需要验证的数据

#         @param cdt_data {dict} 额外的判定条件：

#             “key_maxlength”:允许的字符串最大长度

#             “key_msgtitle”:返回的错误信息标题

#         return {dict} 验证后的信息
#         '''
#         if kw and kw['cdt_data']:
#             self.cdt_data = kw['cdt_data']
#         for key in data:
#             if key == 'name':
#                 self.return_msg = self.name(data[key])
#                 if self.return_msg == True:
#                     continue
#                 return self.return_msg
#             if key == 'sort':
#                 self.return_msg = self.sort(data[key])
#                 if self.return_msg == True:
#                     continue
#                 return self.return_msg
#             if key == 'title':
#                 self.return_msg = self.title(data[key])
#                 if self.return_msg == True:
#                     continue
#                 return self.return_msg
#             if key == 'language':
#                 self.return_msg = self.language(data[key])
#                 if self.return_msg == True:
#                     continue
#                 return self.return_msg
#             if key == 'digest':
#                 self.return_msg = self.digest(data[key])
#                 if self.return_msg == True:
#                     continue
#                 return self.return_msg
#             if key == 'tag':
#                 self.return_msg = self.tag(data[key])
#                 if self.return_msg == True:
#                     continue
#                 return self.return_msg
#             if key == 'email':
#                 self.return_msg = self.email(data[key])
#                 if self.return_msg == True:
#                     continue
#                 return self.return_msg
#             if key == 'content':
#                 self.return_msg = self.content(data[key])
#                 if self.return_msg == True:
#                     continue
#                 return self.return_msg
#         return data

#     def name(self, val):
#         '''
#         各类名称/姓名
#         '''
#         returnMsg = True
#         max_length = self.cdt_data['name_maxlength'] or 50
#         msg_title = self.cdt_data['name_msgtitle'] or '名称'
#         # if self.cdt_data['name_maxlength']:
#         #     max_length = self.cdt_data['name_maxlength']
#         # if self.cdt_data['name_msgtitle']:
#         #     msg_title=self.cdt_data['name_msgtitle']
#         if val == '':
#             returnMsg = self.msgManage.creat_abnormalMsg(
#                 msg=msg_title+'不能为空'
#             )
#         if len(val) > max_length:
#             returnMsg = self.msgManage.creat_abnormalMsg(
#                 msg=msg_title+'过长，限制'+max_length/2+"字"
#             )
#         val = self.strdeal.filter_str(val)
#         return returnMsg

#     def sort(self, val):
#         '''
#         排序字段
#         '''
#         returnMsg = True
#         if self.re.check_num(val) == False:
#             returnMsg = self.msgManage.creat_abnormalMsg(msg='排序值必须为0或正整数')
#         return returnMsg

#     def title(self, val):
#         '''
#         标题
#         '''
#         returnMsg = True
#         if val == '':
#             returnMsg = self.msgManage.creat_abnormalMsg(msg='标题不能为空')
#         if len(val) > 500:
#             returnMsg = self.msgManage.creat_abnormalMsg(msg='标题过长')
#         return returnMsg

#     def language(self, val):
#         '''
#         文章语言版本
#         '''
#         returnMsg = True
#         laArr = ['zh', 'en']
#         if val not in laArr:
#             returnMsg = self.msgManage.creat_abnormalMsg(msg='错误的操作')
#         return returnMsg

#     def digest(self, val):
#         '''
#         文章摘要
#         '''
#         returnMsg = True
#         if len(val) > 500:
#             returnMsg = self.msgManage.creat_abnormalMsg(msg='摘要内容过长')
#         return returnMsg

#     def tag(self, val):
#         '''
#         标签
#         '''
#         returnMsg = True
#         if len(val) > 255:
#             returnMsg = self.msgManage.creat_abnormalMsg(msg='标签内容过长')
#         return returnMsg

#     def email(self, val):
#         '''
#         邮箱
#         '''
#         returnMsg = True
#         if val == '':
#             returnMsg = self.msgManage.creat_abnormalMsg(msg='邮箱不能为空')
#         b = self.re.email(val)
#         if b == False:
#             returnMsg = self.msgManage.creat_abnormalMsg(msg='邮箱格式错误')
#         return returnMsg

#     def content(self, val):
#         '''
#         内容
#         '''
#         returnMsg = True
#         if val == '':
#             returnMsg = self.msgManage.creat_abnormalMsg(msg='内容不能为空')
#         val = self.strdeal.filter_str(val)
#         return returnMsg


# class Net_Request:
#     def __init__(self):
#         pass

#     def get(self, url, params):
#         res = requests.get(url=url, params=params)
#         return res.text

#     def post_text(self, url, data):
#         res = requests.post(url=url, data=data)
#         return res.text

#     def post_content(self, url, data):
#         res = requests.post(url=url, data=data)
#         return res.content


import time
import datetime


class TimeClass:
    def __init__(self) -> None:
        pass

    def localdate(self):
        '''
        获取格式化的当前日期
        return {str} 示例：2000-12-12
        '''
        return time.strftime('%Y-%m-%d', time.localtime())

    def localtime(self):
        '''
        获取格式化的当前时间
        return {str} 示例：2000-12-12 18:18:18
        '''
        return time.strftime('%Y-%m-%d %H:%M:%S', time.localtime())

    def timestamp(self):
        '''
        获取当前时间的时间戳
        return {str}
        '''
        return int(time.time())

    def tampToDate(self,tamp):
        '''
        将时间戳转化为指定时间格式
        return {str} 示例：2000-12-12
        '''
        local_time=time.localtime(tamp/1000)
        return time.strftime('%Y-%m-%d', local_time)

    # def timediff(time1, time2):
    #     '''
    #     计算time1与time2的时间差
    #     :param time1 time1
    #     :param time2 time2
    #     return {str}
    #     '''
    #     time1 = time.strptime('%Y-%m-%d %H:%M:%S', time1)
    #     time2 = time.strptime('%Y-%m-%d %H:%M:%S', time2)
    #     timeStamp1 = int(time.mktime(time1))
    #     timeStamp2 = int(time.mktime(time2))
    #     return timeStamp2-timeStamp1

class DateClass:
    def __init__(self):
        pass

    def get_timestamp(self):
        '''
        获取当前时间戳
        '''
        return int(time.time())

    def compare_date(self, startdate, enddate):
        '''比较日期大小，计算结果为结束日期减起始日期

        :param startdate {string}  起始日期
        :param enddate {string}  结束日期
        return {number} 相差天数
        '''
        starttime = datetime.datetime.strptime(startdate, '%Y-%m-%d')
        endtime = datetime.datetime.strptime(enddate, '%Y-%m-%d')
        delta = endtime-starttime
        return delta.days

    def compare_time(self, starttime, endtime):
        '''比较时间大小，计算结果为结束时间减起始时间

        :param starttime {string}  起始时间
        :param endtime {string}  结束时间
        return {number} 相差秒
        '''
        starttime = datetime.datetime.strptime(starttime, '%H:%M:%S')
        endtime = datetime.datetime.strptime(endtime, '%H:%M:%S')
        delta = endtime-starttime
        if delta.days < 0:
            return -1
        return delta.seconds

    def add_date(self, initdate, days):
        """
        从指定日期添加天数
        :param initdate 初始日期
        :param days 需要添加的天数
        return 字符串格式日期
        """
        d = datetime.datetime.strptime(initdate, '%Y-%m-%d')
        d = d+datetime.timedelta(days=days)
        return d.strftime('%Y-%m-%d')

    def get_nowDate(self):
        '''获取当前日期，格式yyyy-MM-dd'''
        return time.strftime('%Y-%m-%d', time.localtime())

    def datestrFormate(self, date):
        '''将日期字符串转化为日期对象'''
        return datetime.datetime.strptime(date, '%Y-%m-%d')

    def timestrFormate(self, time):
        '''将时间字符串转化为时间对象'''
        return datetime.datetime.strptime(time, '%H:%M:%S')

    def checkTimeSection(self, time, starttime, endtime):
        '''判断时间是否在指定范围内(等于前后时间)，日期格式HH:mm:ss\n
        :param time {str} 需要判断的时间\n
        :param starttime {str} 起始时间\n
        :param endtime {str} 结束时间\n
        return {bool} True/False
        '''
        if len(time) == 5:
            time = time+':00'
        if len(starttime) == 5:
            starttime = starttime+':00'
        if len(endtime) == 5:
            endtime = endtime+':00'
        leftS = self.compare_time(starttime, time)
        rightS = self.compare_time(time, endtime)
        if leftS >= 0 and rightS >= 0:
            return True
        return False



if __name__=='__main__':
    pass




import random
import hashlib
import binascii
import os
import json
import re
import html
from pymoran.timetool import TimeClass


class StrClass:
    def __init__(self) -> None:
        pass

    def random_num(self, length: int):
        '''
        创建纯数字随机字符串
        :param length 生成的字符串长度
        :return {str} 生成的随机字符串
        '''
        result = ''
        pool = '0123456789'
        pool_len = len(pool)-1
        for i in range(length):
            result += pool[random.randint(0, pool_len)]
        return result

    def random_str(self, length: int):
        '''
        创建包含大小写字母和数字的随机字符串
        :param length 生成的字符串长度
        :return {str} 生成的随机字符串
        '''
        result = ''
        pool = 'AaBbCcDdEeFfGgHhIiJjKkLlMmNnOoPpQqRrSsTtUuVvWwXxYyZz0123456789'
        pool_len = len(pool)-1
        for i in range(length):
            result += pool[random.randint(0, pool_len)]
        return result

    def custom_random_str(self, pool: str, length: int):
        '''
        创建自定义范围的随机字符串
        :param pool 自定义字符串范围
        :param length 生成的字符串长度
        :return {str} 生成的随机字符串
        '''
        result = ''
        pool_len = len(pool)-1
        for i in range(length):
            result += pool[random.randint(0, pool_len)]
        return result

    def hash_md5(self, enstr):
        """
        字符串md5加密
        :param enstr 需要加密的字符串
        :return {str} 加密后的字符串
        """
        md = hashlib.md5()
        md.update(bytes(enstr, encoding='utf-8'))
        result = md.hexdigest()
        return result

    def hash_sha1(self, enstr):
        """
        字符串sha1加密
        :param enstr 需要加密的字符串
        :return {str} 加密后的字符串
        """
        sha = hashlib.sha1()
        sha.update(bytes(enstr, encoding='utf-8'))
        result = sha.hexdigest()
        return result

    def password(self, pwd: str, salt: str):
        """
        根据原密码加盐获取新的加密密码
        :param pwd 原密码
        :param salt 盐值，盐值长度必须大于4
        :return {str} 加密后的密码
        """
        salt1 = salt[0:4]
        salt2 = salt[4:]
        pwd = salt1+pwd+salt2
        return self.hash_md5(pwd)

    def access_token(self, uniqueid: str):
        """
        生成唯一access_token
        :param uniqueid 唯一id
        :return {str}
        """
        timeclass = TimeClass()
        result = str(uniqueid)+str(timeclass.timestamp())
        result = self.hash_md5(result)
        result = result + str(binascii.b2a_base64(os.urandom(108))[:-1])
        result = result.replace('\'', '')
        result = result.replace('/', '')
        return result

    def html_escape(self, value: str):
        '''
        对传输的值进行html编码
        :param value 需要转换的字符串
        :return 编码后的字符串
        '''
        if type(value) == int:
            return str(value)
        if value is None:
            return ''
        return html.escape(value)

    def html_unescape(self, value: str, b_json: bool = False):
        '''
        对传输的值进行html解码
        :param value 需要转换的字符串
        :param b_json 是否将json字符串转化为Python对象
        :return 解码后的字符串
        '''
        value=html.unescape(value)
        if b_json:
            value=json.loads(value)
        return value

    # def symbol_replace(self,value):
    #     '''
    #     替换文本中的特殊字符
    #     :param value {str} 需要替换的字符串
    #     :return {str} 替换后的字符串
    #     '''
    #     value=value.replace('\'','&#39;')
    #     value=value.replace('´','&#180;')
    #     value=value.replace('`','&#96;')
    #     return value

    


class JsonClass:
    def __init__(self):
        pass

    def jsonToDumps(self, data: dict):
        '''
        将字典类型数据转换成str
        :param data 字典类型数据
        :return {str} 转换后的json格式字符串
        '''
        return json.dumps(data,ensure_ascii=False)

    def jsonToLoads(self, jsonstr: str):
        '''
        将json字符串数据转换成字典类型
        :param jsonstr json字符串
        :return {dict} 转换后的dict数据
        '''
        if jsonstr == None:
            return jsonstr
        elif type(jsonstr) == bytes:
            jsonstr = jsonstr.decode()
        return json.loads(jsonstr)

    # def jsonQuerySetToDumps(self, data):
    #     '''
    #     转换QuerySet类型数据并输出json格式字符串
    #     :param data {QuerySet} QuerySet/list数据
    #     :return {str} 转换后的json格式字符串
    #     '''
    #     if type(data) != list:
    #         data = list(data)
    #     result = json.dumps(data, ensure_ascii=False, cls=DjangoJSONEncoder)
    #     return result

    # def jsonQuerySetToLoads(self, data):
    #     '''
    #     转换QuerySet类型数据并输出dict

    #     @param data {QuerySet} QuerySet/list数据

    #     return {dict} 转换后的dict数据
    #     '''
    #     result = self.jsonQuerySetToDumps(data)
    #     result = json.loads(result)
    #     return result


class RegularClass:
    def __init__(self):
        pass
    
    '''数字'''
    def pInt(self, value: str, include_zero: bool = True):
        '''
        正整数
        :param value 需要验证的字符串
        :param include_zero 是否包含0，默认True，包含
        :return {bool} 验证结果，True/False
        '''
        value = str(value)
        result = ''
        if include_zero:
            result = re.match(r'^[0-9]+$', value)
        else:
            result = re.match(r'^[1-9]\d*$', value)
        if result:
            return True
        return False
    
    def zero_pint(self, val):
        '''
        0和正整数
        '''
        val = str(val)
        result = re.match(r'^\d+$', val)
        if result:
            return True
        return False

    def price(self, value):
        '''
        价钱
        :param value 需要验证的字符串
        :return {bool} 验证结果，True/False
        '''
        result = re.match(r'^[0-9]+(.[0-9]{2})?$', value)
        if result:
            return True
        return False

    def username(self, value):
        '''
        用户名
        :param value 需要验证的字符串
        :return {bool} 验证结果，True/False
        '''
        result = re.match(r'^[a-zA-Z0-9_-]{4,20}$', value)
        if result:
            return True
        return False

    def phone(self, value):
        '''
        手机号
        :param value 需要验证的字符串
        :return {bool} 验证结果，True/False
        '''
        result = re.match(r'^1[3456789]\d{9}$', value)
        if result:
            return True
        return False

    def password(self, value):
        '''
        密码
        :param value 需要验证的字符串
        :return {bool} 验证结果，True/False
        '''
        result = re.match(r'^[\w!@#$%^&*.]{6,20}$', value)
        if result:
            return True
        return False

    def ipv4(self, value):
        '''
        ipv4
        :param value 需要验证的字符串
        :return {bool} 验证结果，True/False
        '''
        result = re.match(
            r'^(((\d{1,2})|(1\d{2})|(2[0-4]\d)|(25[0-5]))\.){3}((\d{1,2})|(1\d{2})|(2[0-4]\d)|(25[0-5]))$',
            value
        )
        if result:
            return True
        return False

    def email(self, value):
        '''
        email
        :param value 需要验证的字符串
        :return {bool} 验证结果，True/False
        '''
        result = re.match(
            r'^[a-zA-Z0-9_-]+@[a-zA-Z0-9_-]+(\.[a-zA-Z0-9_-]+)+$',
            value
        )
        if result:
            return True
        return False


if __name__ == '__main__':
    regular = RegularClass()
    regular.pInt('erwer')
